#
# spec file for package python-django-celery-beat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-celery-beat
Version:        2.6.0
Release:        1.3
Summary:        Database-backed Periodic Tasks
License:        BSD-3-Clause
URL:            https://github.com/celery/django-celery-beat
Source:         https://files.pythonhosted.org/packages/source/d/django-celery-beat/django-celery-beat-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module celery >= 5.2.3}
BuildRequires:  %{python_module Django >= 3.2}
BuildRequires:  %{python_module case >= 1.3.1}
BuildRequires:  %{python_module cron-descriptor >= 1.2.32}
BuildRequires:  %{python_module django-timezone-field >= 5.0}
BuildRequires:  %{python_module ephem}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module pytest >= 6.2.5}
BuildRequires:  %{python_module pytest-django >= 4.5.2}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module python-crontab >= 2.3.4}
BuildRequires:  %{python_module tzdata}
BuildRequires:  timezone
# /SECTION
BuildRequires:  fdupes
Requires:       python-Django >= 3.2
Requires:       python-celery >= 5.2.3
Requires:       python-cron-descriptor >= 1.2.32
Requires:       python-django-timezone-field >= 5.0
Requires:       python-python-crontab >= 2.3.4
Requires:       python-tzdata
Suggests:       python-importlib-metadata < 5.0
Suggests:       python-backports.zoneinfo
BuildArch:      noarch
%python_subpackages

%description
Database-backed Periodic Tasks.

%prep
%autosetup -p1 -n django-celery-beat-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export DJANGO_SETTINGS_MODULE=t.proj.settings
# test_run_task, test_run_tasks: I see ghosts in the buildlog https://github.com/celery/django-celery-beat/issues/665
%pytest -k "not test_run_task"

%files %{python_files}
%doc AUTHORS Changelog README.rst
%license LICENSE
%{python_sitelib}/django_celery_beat
%{python_sitelib}/django_celery_beat-%{version}.dist-info

%changelog
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.0:
  * Avoid crash when can not get human readable description
  * Update codeql-analysis.yml (#653).
  * Fix CI: Change assert self.app.timezone.zone to assert
    self.app.timezone.key (#664).
  * Drop Django 4.0 from CI to avoid security issues (#662).
  * Fix Issue #388: Celery Beat scheduled tasks may be executed
    repeatedly (#660).
  * Update README.rst (#670).
  * Update runtime.txt to include Django 5.0 (#681).
  * Replace case.patching fixture with mockeypatch + MagicMock
  * Update README.rst - Crontab effect description (#689).
  * Update supported Python & Django version in setup.py (#672).
  * Add Python 3.12 to test matrix and add classifier (#690).
  * Django v5.0: django.utils.timezone.utc alias -->
    datetime.timezone.utc (#703).
  * Upgrade GitHub Actions and PyPy 3.10 and Django 5.0 (#699).
  * Testing Django v5.0 on pypy-3.10-v7.3.14 passes (#705).
  * Prepare for release v2.6.0 to support Py3.12 and Dj5.0
  * GitHub Actions: Do not hardcode an out-of-date version of
    PyPy (#715).
  * Use the same order in the admin as in the cron schedule
    expression (#716).
  * Upgrade pip and GitHub Actions dependencies with dependabot
  * Update pytest requirement from <8.0,>=6.2.5 to >=6.2.5,<9.0
  * Remove requirements/test-djangoXY.txt (#728).
  * Remove code for unsupported django.VERSION < (3, 2) (#729).
  * Added sphinxcontrib-django to extensions (#736).
- drop support-zoneinfo.patch (upstream)
* Tue Feb 13 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-zoneinfo.patch:
  * Use correct method for zoneinfo instances.
* Tue Jul 18 2023 Markéta Machová <mmachova@suse.com>
- Initial packaging (v2.5.0), needed by Weblate
